@@ -20,8 +20,6 @@ NODE_RESERVED_NAMES_CONST <- c(
                                 'clone',
                                 'count',
                                 'Do',
-                                'fields',
-                                'fieldsAll',
                                 'Get',
                                 'GetAttribute',
                                 'height',
@@ -119,7 +117,7 @@ NODE_RESERVED_NAMES_CONST <- c(
 #'
 #'    
 #' @export
-#' @format An \code{\link{R6Class}} generator object
+#' @format An \code{\link[R6:R6Class]{R6Class}} generator object
 Node <- R6Class("Node",
                 lock_objects = FALSE,
                 lock_class = TRUE,
@@ -649,18 +647,6 @@ Node <- R6Class("Node",
                         # match(self$name, names(private$p_parent$children))
                         return (result)
                       },
-                                    
-                      #' @field fields Will be deprecated, use \code{attributes} instead
-                      fields = function() {
-                        .Deprecated("Node$attributes", old = "Node$fields")
-                        return(self$attributes)
-                      },
-                      
-                      #' @field fieldsAll Will be deprecated, use \code{attributesAll} instead
-                      fieldsAll = function() {
-                        .Deprecated("Node$attributesAll", old = "Node$fieldsAll")
-                        return(self$attributesAll)
-                      },
                       
                       #' @field attributes The attributes defined on this specific node        
                       attributes = function() {
