@@ -26,17 +26,17 @@ test_that("totalCount", {
 test_that("Climb", {
   
   
-  node <- acme$Climb("Accounting", "New Accounting Standards")
+  node <- Climb(acme, "Accounting", "New Accounting Standards")
   expect_equal(node$name, "New Accounting Standards")
   
-  node <- acme$Climb("Not existing node")
+  node <- Climb(acme, "Not existing node")
   expect_equal(node, NULL)
   
 })
 
 test_that("isLeaf", {
   
-  node <- acme$Climb("Accounting", "New Accounting Standards")
+  node <- Climb(acme, "Accounting", "New Accounting Standards")
   expect_equal(node$isLeaf, TRUE)
   
 })
@@ -46,7 +46,7 @@ test_that("level", {
   
   expect_equal(acme$isLeaf, FALSE)
   
-  accounting <- acme$Climb("Accounting")
+  accounting <- Climb(acme, "Accounting")
   expect_equal(accounting$isLeaf, FALSE)
   
   node <- accounting$Climb("New Accounting Standards")
